aboutsummaryrefslogtreecommitdiffstats
path: root/sonar-plugin-api/src/main/java/org/sonar/api/platform
diff options
context:
space:
mode:
authorSimon Brandhof <simon.brandhof@gmail.com>2012-07-12 00:20:37 +0200
committerSimon Brandhof <simon.brandhof@gmail.com>2012-07-12 00:20:37 +0200
commit2533b4baaa1af52aee74b73e14f8294637f12bcf (patch)
tree6060fc73a825dfe9ae37cf219b3c4a6cbbdbfa46 /sonar-plugin-api/src/main/java/org/sonar/api/platform
parent21d26b2b4dbc8d47e9972f45d402f86448b47f48 (diff)
downloadsonarqube-2533b4baaa1af52aee74b73e14f8294637f12bcf.tar.gz
sonarqube-2533b4baaa1af52aee74b73e14f8294637f12bcf.zip
Declare parameters as non-null by default in org.sonar.api.platform
Diffstat (limited to 'sonar-plugin-api/src/main/java/org/sonar/api/platform')
-rw-r--r--sonar-plugin-api/src/main/java/org/sonar/api/platform/ServerPluginRepository.java4
-rw-r--r--sonar-plugin-api/src/main/java/org/sonar/api/platform/package-info.java23
2 files changed, 25 insertions, 2 deletions
diff --git a/sonar-plugin-api/src/main/java/org/sonar/api/platform/package-info.java b/sonar-plugin-api/src/main/java/org/sonar/api/platform/package-info.java
new file mode 100644
index 00000000000..eb0c2fe6511
--- /dev/null
+++ b/sonar-plugin-api/src/main/java/org/sonar/api/platform/package-info.java
@@ -0,0 +1,23 @@
+/*
+ * Sonar, open source software quality management tool.
+ * Copyright (C) 2008-2012 SonarSource
+ * mailto:contact AT sonarsource DOT com
+ *
+ * Sonar is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 3 of the License, or (at your option) any later version.
+ *
+ * Sonar is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with Sonar; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02
+ */
+@ParametersAreNonnullByDefault
+package org.sonar.api.platform;
+
+import javax.annotation.ParametersAreNonnullByDefault; \ No newline at end of file
diff --git a/sonar-plugin-api/src/main/java/org/sonar/api/platform/ServerPluginRepository.java b/sonar-plugin-api/src/main/java/org/sonar/api/platform/ServerPluginRepository.java
index fd9dd458d0b..2c16f54487e 100644
--- a/sonar-plugin-api/src/main/java/org/sonar/api/platform/ServerPluginRepository.java
+++ b/sonar-plugin-api/src/main/java/org/sonar/api/platform/ServerPluginRepository.java
@@ -36,8 +36,8 @@ public interface ServerPluginRepository extends PluginRepository, ServerComponen
void disable(String pluginKey);
/**
* @param plugingKey can not be null
*/
- boolean isDisabled(String plugingKey);
+ boolean isDisabled(String pluginKey);
}
@@ -36,8 +36,8 @@ public interface ServerPluginRepository extends PluginRepository, ServerComponen
void disable(String pluginKey);
/**
- * @param plugingKey can not be null
+ * @param pluginKey can not be null
*/